==> zio-aws-kafka_3-5.17.147.1-sources.jar: zio/aws/kafka/model/Unauthenticated.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__boolean
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class Unauthenticated(enabled: Option[__boolean] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.Unauthenticated = {
    import Unauthenticated.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.Unauthenticated
      .builder()
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.Unauthenticated.ReadOnly =
    zio.aws.kafka.model.Unauthenticated.wrap(buildAwsValue())
}
object Unauthenticated {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.Unauthenticated
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.Unauthenticated =
      zio.aws.kafka.model.Unauthenticated(enabled.map(value => value))
    def enabled: Option[__boolean]
    def getEnabled: ZIO[Any, AwsError, __boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.Unauthenticated
  ) extends zio.aws.kafka.model.Unauthenticated.ReadOnly {
    override val enabled: Option[__boolean] =
      scala.Option(impl.enabled()).map(value => value: __boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.Unauthenticated
  ): zio.aws.kafka.model.Unauthenticated.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kafka_3-5.17.177.1-sources.jar: zio/aws/kafka/model/Unauthenticated.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__boolean
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class Unauthenticated(
    enabled: Optional[__boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.Unauthenticated = {
    import Unauthenticated.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.Unauthenticated
      .builder()
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.Unauthenticated.ReadOnly =
    zio.aws.kafka.model.Unauthenticated.wrap(buildAwsValue())
}
object Unauthenticated {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.Unauthenticated
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.Unauthenticated =
      zio.aws.kafka.model.Unauthenticated(enabled.map(value => value))
    def enabled: Optional[__boolean]
    def getEnabled: ZIO[Any, AwsError, __boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.Unauthenticated
  ) extends zio.aws.kafka.model.Unauthenticated.ReadOnly {
    override val enabled: Optional[__boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.enabled())
      .map(value => value: __boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.Unauthenticated
  ): zio.aws.kafka.model.Unauthenticated.ReadOnly = new Wrapper(impl)
}
